NAME
Sisimai::Group::Phone - Major phone provider's domains in the world
SYNOPSIS
use Sisimai::Group::Phone;
print Sisimai::Group::Phone->find('nokiamail.com'); # nokia
DESCRIPTION
Sisimai::Group::Phone has a domain list of major cellular phone providers and major smart phone providers of the world.
CLASS METHODS
find( domain )
domain() returns a category name found by the domain name from domain list.
print Sisimai::Group::Phone->find('nokiamail.com'); # nokia
AUTHOR
azumakuniyuki
COPYRIGHT
Copyright (C) 2014 azumakuniyuki <perl.org@azumakuniyuki.org>, All Rights Reserved.
LICENSE
This software is distributed under The BSD 2-Clause License.